@@ -115,6 +115,7 @@ def create_model_version(
         model_type (str): Model type (also known as objective). The supported model types are:
             * "regression" - for regression models
             * "binary" - for binary classification models
+            * "multiclass" - for multiclass classification models
         features (Dict[str, str]): Schema for model features (See notes)
         predictions (Dict[str, str]): Schema for prediction results (See notes)
         raw_inputs (Dict[str, str], optional): Schema for raw inputs (See notes). Defaults to None.
@@ -146,10 +147,7 @@ def create_model_version(
             raise AporiaError("model_id and model_version must be non-empty strings.")
 
         validate_fields_input(
-            features=features,
-            predictions=predictions,
-            raw_inputs=raw_inputs,
-            metrics=metrics,
+            features=features, predictions=predictions, raw_inputs=raw_inputs, metrics=metrics,
         )
 
         context.event_loop.run_coroutine(
