@@ -14,7 +14,7 @@ try:
     TRAINING_ENABLED = True
 
 except ImportError:
-    ndarray = Any
+    ndarray = Any  # type: ignore
     DataFrame = Any
     TRAINING_ENABLED = False
 
